@@ -30,14 +30,14 @@ static t_uchar * version_string = (cfg__std__package " from regexps.com\n"
                                    cfg__std__release_id_string
                                    "\n");
 
-#define OPTS(OP, OP2) \
+#define OPTS(OP) \
   OP (opt_help_msg, "h", "help", 0, \
       "Display a help message and exit.") \
   OP (opt_long_help, "H", 0, 0, \
       "Display a verbose help message and exit.") \
   OP (opt_version, "V", "version", 0, \
-      "Display a release identifier string") \
-  OP2 (opt_version, 0, 0, 0, "and exit.") \
+      "Display a release identifier string\n" \
+      "and exit.") \
   OP (opt_broken_symlink, "s", "broken-symlinks", 0, \
       "Just list broken symlinks") \
   OP (opt_unrecognized_files, "u", "unrecognized-files", 0, \
@@ -61,12 +61,12 @@ t_uchar arch_cmd_tree_lint_help[] = ("audit a source tree\n"
 
 enum options
 {
-  OPTS (OPT_ENUM, OPT_IGN)
+  OPTS (OPT_ENUM)
 };
 
 static struct opt_desc opts[] =
 {
-  OPTS (OPT_DESC, OPT_DESC)
+  OPTS (OPT_DESC)
     {-1, 0, 0, 0, 0}
 };
 
